==> haskell-asn1-parse-0.9.4-64-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-2URiOy9yDPr2rjtdFoeqR3
key: asn1-parse-0.9.4-2URiOy9yDPr2rjtdFoeqR3
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: e89ac0ab99642c80fc1d167d0a0f1714
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-2URiOy9yDPr2rjtdFoeqR3
depends:
    asn1-encoding-0.9.5-HWb0L2GGxyS70q6izFc6sA
    asn1-types-0.3.2-8nd3OIApP3tImhL7NQa8PW base-4.11.1.0
    bytestring-0.10.8.2
abi-depends: asn1-encoding-0.9.5-HWb0L2GGxyS70q6izFc6sA=e678dfcd41343eec83f99c61c5389044
             asn1-types-0.3.2-8nd3OIApP3tImhL7NQa8PW=096abbb25fc6498ea1fc69964a216c83
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-asn1-parse-0.9.4-66-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-asn1-parse.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: asn1-parse
version: 0.9.4
id: asn1-parse-0.9.4-5n2dMGQge231SBfa0Hdn6i
key: asn1-parse-0.9.4-5n2dMGQge231SBfa0Hdn6i
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: https://github.com/vincenthz/hs-asn1
synopsis: Simple monadic parser for ASN1 stream types.
description:
    Simple monadic parser for ASN1 stream types, when ASN1 pattern matching is not convenient.
category: Data
abi: 5bd085e84f8c05729dca9089926922cf
exposed: True
exposed-modules:
    Data.ASN1.Parse
import-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/asn1-parse-0.9.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/asn1-parse-0.9.4
hs-libraries: HSasn1-parse-0.9.4-5n2dMGQge231SBfa0Hdn6i
depends:
    asn1-encoding-0.9.5-7oYKg2eybhQ3jGfjPdw6mX
    asn1-types-0.3.2-LpybkVR8uyq6OmNI84IhEv base-4.11.1.0
    bytestring-0.10.8.2
abi-depends: asn1-encoding-0.9.5-7oYKg2eybhQ3jGfjPdw6mX=a26873daf0ae53af9cc829bc56ec4dab
             asn1-types-0.3.2-LpybkVR8uyq6OmNI84IhEv=4df8e19df99ad8b30a37ab5299bc55b6
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
haddock-interfaces: /usr/share/doc/haskell-asn1-parse/html/asn1-parse.haddock
haddock-html: /usr/share/doc/haskell-asn1-parse/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
